==> firefox-58.0b13.source.tar.xz: firefox-58.0b13/browser/extensions/activity-stream/prerendered/locales/ml/activity-stream-strings.js <==
// Note - this is a generated file.
window.gActivityStreamStrings = {
  "newtab_page_title": "പുതിയ ടാബ്",
  "default_label_loading": "ലോഡ്ചെയ്യുന്നു…",
  "header_top_sites": "മികച്ച സൈറ്റുകൾ",
  "header_stories": "മികച്ച ലേഖനങ്ങൾ",
  "header_highlights": "ഹൈലൈറ്റുകൾ",
  "header_visit_again": "വീണ്ടും സന്ദർശിക്കുക",
  "header_bookmarks": "അടുത്തിടെയുള്ള ബുക്ക്മാർക്കുകൾ",
  "header_recommended_by": "{provider} ശുപാർശ ചെയ്തത്",
  "header_bookmarks_placeholder": "നിങ്ങൾക്ക് ഇതുവരെ ബുക്ക്മാർക്കുകൾ ഇല്ല.",
  "header_stories_from": "എവിടെ നിന്നും",
  "type_label_visited": "സന്ദർശിച്ചത്‌",
  "type_label_bookmarked": "അടയാളപ്പെടുത്തിയത്",
  "type_label_synced": "മറ്റു ഉപകരണങ്ങളുമായി സാമ്യപ്പെടുക",
  "type_label_recommended": "ട്രെൻഡിംഗ്",
  "type_label_open": "തുറക്കുക",
  "type_label_topic": "വിഷയം",
  "type_label_now": "ഇപ്പോൾ",
  "menu_action_bookmark": "അടയാളം",
  "menu_action_remove_bookmark": "അടയാളം മാറ്റുക",
  "menu_action_copy_address": "വിലാസം പകർത്തുക",
  "menu_action_email_link": "ഇമെയിൽ വിലാസം…",
  "menu_action_open_new_window": "പുതിയ ജാലകത്തിൽ തുറക്കുക",
  "menu_action_open_private_window": "പുതിയ രസഹ്യജാലകത്തിൽ തുറക്കുക",
  "menu_action_dismiss": "പുറത്താക്കുക",
  "menu_action_delete": "ചരിത്രത്തിൽ നിന്ന് ഒഴിവാക്കുക",
  "menu_action_pin": "പിൻ ചെയ്യുക",
  "menu_action_unpin": "അൺപിൻ ചെയ്യുക",
  "confirm_history_delete_p1": "നിങ്ങളുടെ ചരിത്രത്തിൽ നിന്ന് ഈ പേജിന്റെ എല്ലാ ഉദാഹരണങ്ങളും ഇല്ലാതാക്കാൻ നിങ്ങൾ താൽപ്പര്യപ്പെടുന്നുവെന്ന് തീർച്ചയാണോ?",
  "confirm_history_delete_notice_p2": "ഈ പ്രവർത്തനം പഴയപടിയാക്കാനാവില്ല.",
  "menu_action_save_to_pocket": "പോക്കറ്റിലേയ്ക്ക് സംരക്ഷിയ്ക്കുക",
  "search_for_something_with": "തിരയാൻ {search_term} : എന്നത് ഉപയോഗിയ്ക്കുക",
  "search_button": "തിരയുക",
  "search_header": "{search_engine_name} തിരയുക",
  "search_web_placeholder": "ഇൻറർനെറ്റിൽ തിരയുക",
  "search_settings": "തിരയാനുള്ള രീതികൾ മാറ്റുക",
  "section_info_option": "വിവരം",
  "section_info_send_feedback": "ഫീഡ്ബാക്ക് അയയ്ക്കുക",
  "section_info_privacy_notice": "സ്വകാര്യതാ അറിയിപ്പ്",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "welcome_title": "പുതിയ ജാലകത്തിലേക്കു സ്വാഗതം",
  "welcome_body": "നിങ്ങളുടെ ഏറ്റവും ശ്രദ്ധേയമായ അടയാളങ്ങൾ, ലേഖനങ്ങൾ, വീഡിയോകൾ, കൂടാതെ നിങ്ങൾ സമീപകാലത്ത് സന്ദർശിച്ച താളുകൾ എന്നിവ കാണിക്കുന്നതിനായി ഫയർഫോക്സ് ഈ ഇടം ഉപയോഗിക്കും, അതിനാൽ നിങ്ങൾക്ക് എളുപ്പത്തിൽ അവയിലേക്ക് തിരിച്ചു പോകാം.",
  "welcome_label": "താങ്കളുടെ ഹൈലൈറ്റ്സ് തിരിച്ചറിയുന്നു",
  "time_label_less_than_minute": "<1 മിനിറ്റ്",
  "time_label_minute": "{number} മിനിറ്റ്",
  "time_label_hour": "{number} മിനിറ്റ്",
  "time_label_day": "{number} മിനിറ്റ്",
  "settings_pane_button_label": "നിങ്ങളുടെ പുതിയ ടാബ് താള് ഇഷ്ടാനുസൃതമാക്കുക",
  "settings_pane_header": "പുതിയ ടാബിന്റെ മുൻഗണനകൾ",
  "settings_pane_body2": "നിങ്ങൾ ഈ താളിൽ കാണുന്നത് തിരഞ്ഞെടുക്കുക.",
  "settings_pane_search_header": "തിരയുക",
  "settings_pane_search_body": "പുതിയ ടാബിൽ നിന്ന് ഇന്റർനെറ്റിൽ തിരയുക.",
  "settings_pane_topsites_header": "മുന്നേറിയ സൈറ്റുകൾ",
  "settings_pane_topsites_body": "നിങ്ങൾ കൂടുതൽ സന്ദർശിക്കുന്ന വെബ്‌സൈറ്റുകളിൽ പ്രവേശിക്കുക.",
  "settings_pane_topsites_options_showmore": "രണ്ടു വരികൾ കാണിയ്ക്കുക",
  "settings_pane_bookmarks_header": "അടുത്തിടെയുള്ള ബുക്ക്മാർക്കുകൾ",
  "settings_pane_bookmarks_body": "നിങ്ങളുടെ പുതിയതായി സൃഷ്ടിച്ച ബുക്ക്മാർക്കുകൾ ഒരു സ്ഥലത്ത്.",
  "settings_pane_visit_again_header": "വീണ്ടും സന്ദർശിക്കുക",
  "settings_pane_visit_again_body": "നിങ്ങൾ ഓർത്തുവയ്ക്കാനോ അല്ലെങ്കിൽ തിരികെ ചെല്ലാനോ ആഗ്രഹിക്കുന്ന ബ്രൌസിംഗ് ചരിത്രത്തിന്റെ ഭാഗങ്ങൾ നിങ്ങൾക്ക് ഫയർഫോക്സ് കാണിച്ച് തരും.",
  "settings_pane_highlights_header": "ഹൈലൈറ്റുകൾ",
  "settings_pane_highlights_body2": "നിങ്ങൾ സമീപകാലത്ത് സന്ദർശിച്ചതോ അല്ലെങ്കിൽ ബുക്ക്മാർക്ക് ചെയ്തതോ ആയ രസകരമായ കാര്യങ്ങളിലേക്ക് വഴി കണ്ടെത്തുക.",
  "settings_pane_highlights_options_bookmarks": "ബുക്ക്മാർക്കുകൾ",
  "settings_pane_highlights_options_visited": "സന്ദർശിച്ച സൈറ്റുകൾ",
  "settings_pane_snippets_header": "ലഘു കുറിപ്പുകൾ",
  "settings_pane_snippets_body": "മോസില്ലയിൽ നിന്നും ഫയർഫോക്സ്, ഇന്റർനെറ്റ് സംസ്കാരം, വല്ലപ്പോഴുമുള്ള ക്രമമില്ലാത്ത മെമെ, എന്നിവയിൽ ചെറുതും മധുരവുമായ പരിഷ്കരണങ്ങൾ വായിക്കുക.",
  "settings_pane_done_button": "തീർന്നു",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "edit_topsites_button_text": "തിരുത്തുക",
  "edit_topsites_button_label": "നിങ്ങളുടെ മുന്നേറിയ സൈറ്റുകളുടെ വിഭാഗം ഇഷ്ടാനുസൃതമാക്കുക",
  "edit_topsites_showmore_button": "കൂടുതൽ കാണിക്കുക",
  "edit_topsites_showless_button": "കുറച്ച് കാണിക്കുക",
  "edit_topsites_done_button": "തീർന്നു",
  "edit_topsites_pin_button": "ഈ സൈറ്റ് പിൻ ചെയ്യുക",
  "edit_topsites_unpin_button": "ഈ സൈറ്റ് അണ്‍പിന്‍ ചെയ്യുക",
  "edit_topsites_edit_button": "ഈ സൈറ്റ് തിരുത്തുക",
  "edit_topsites_dismiss_button": "ഈ സൈറ്റ് പുറത്താക്കുക",
  "edit_topsites_add_button": "ചേര്‍ക്കുക",
  "topsites_form_add_header": "പുതിയ മികച്ച സൈറ്റുകൾ",
  "topsites_form_edit_header": "മികച്ച സൈറ്റ് ലിസ്റ്റ് തിരുത്തൂ",
  "topsites_form_title_placeholder": "തലക്കെട്ട് നൽകൂ",
  "topsites_form_url_placeholder": "വെബ്URLനൽകൂ",
  "topsites_form_add_button": "ചേർക്കൂ",
  "topsites_form_save_button": "സംരക്ഷിയ്ക്കൂ",
  "topsites_form_cancel_button": "ഒഴിവാക്കൂ",
  "topsites_form_url_validation": "പ്രവർത്തിയ്ക്കുന്ന URL ആവശ്യമാണ്",
  "pocket_read_more": "ജനപ്രിയ വിഷയങ്ങൾ:",
  "pocket_read_even_more": "കൂടുതൽ ലേഖനങ്ങൾ കാണുക",
  "pocket_feedback_header": "250 ലക്ഷം പേരാൽ തെരഞ്ഞെടുക്കപ്പെട്ട വെബിലെ ഏറ്റവും മികച്ചവയാണിവ.",
  "pocket_description": "മോസില്ലയുടെ ഭാഗമായ, പോക്കറ്റിന്റെ സഹായം കൊണ്ട്, നിങ്ങൾക്ക് കണ്ടെത്താനാവാത്ത ഉയർന്ന നിലവാരമുള്ള ഉള്ളടക്കം കണ്ടെത്തുക.",
  "highlights_empty_state": "ബ്രൗസിംഗ് ആരംഭിക്കുക, നിങ്ങൾ സമീപകാലത്ത് സന്ദർശിച്ചതോ ബുക്ക്മാർക്ക് ചെയ്തതോ ആയ മികച്ച ലേഖനങ്ങളിൽ നിന്നോ, വീഡിയോകളിൽ നിന്നോ, മറ്റു പേജുകളിൽ നിന്നോ ചിലത് ഞങ്ങൾ ഇവിടെ കാണിക്കും.",
  "topstories_empty_state": "നിങ്ങൾ ഇവിടെ വരെ എത്തി. {Provider}ൽ നിന്നുള്ള കൂടുതൽ പ്രധാന വാർത്തകൾക്കായി പിന്നീട് വീണ്ടും പരിശോധിക്കുക. കാത്തിരിക്കാൻ പറ്റില്ലേ? വെബിൽ നിന്ന് കൂടുതൽ മികച്ച കഥകൾ കണ്ടെത്തുന്നതിന് ഒരു ജനപ്രിയ വിഷയം തിരഞ്ഞെടുക്കുക.",
  "manual_migration_explanation2": "മറ്റൊരു ബ്രൗസറിൽ നിന്നുള്ള ബുക്ക്മാർക്കുകൾ, ചരിത്രം, പാസ്വേഡുകൾ എന്നിവ ഉപയോഗിച്ച് ഫയർഫോക്സ് പരീക്ഷിക്കുക.",
  "manual_migration_cancel_button": "വേണ്ട, നന്ദി",
  "manual_migration_import_button": "ഇപ്പോൾ ഇറക്കുമതി ചെയ്യുക"
};

==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/ml/activity-stream-strings.js <==
// Note - this is a generated ml file.
window.gActivityStreamStrings = {
  "newtab_page_title": "പുതിയ ടാബ്",
  "header_top_sites": "മികച്ച സൈറ്റുകൾ",
  "header_highlights": "ഹൈലൈറ്റുകൾ",
  "header_recommended_by": "{provider} ശുപാർശ ചെയ്തത്",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "സന്ദർശിച്ചത്‌",
  "type_label_bookmarked": "അടയാളപ്പെടുത്തിയത്",
  "type_label_recommended": "ട്രെൻഡിംഗ്",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "അടയാളം",
  "menu_action_remove_bookmark": "അടയാളം മാറ്റുക",
  "menu_action_open_new_window": "പുതിയ ജാലകത്തിൽ തുറക്കുക",
  "menu_action_open_private_window": "പുതിയ രസഹ്യജാലകത്തിൽ തുറക്കുക",
  "menu_action_dismiss": "പുറത്താക്കുക",
  "menu_action_delete": "ചരിത്രത്തിൽ നിന്ന് ഒഴിവാക്കുക",
  "menu_action_pin": "പിൻ ചെയ്യുക",
  "menu_action_unpin": "അൺപിൻ ചെയ്യുക",
  "confirm_history_delete_p1": "നിങ്ങളുടെ ചരിത്രത്തിൽ നിന്ന് ഈ പേജിന്റെ എല്ലാ ഉദാഹരണങ്ങളും ഇല്ലാതാക്കാൻ നിങ്ങൾ താൽപ്പര്യപ്പെടുന്നുവെന്ന് തീർച്ചയാണോ?",
  "confirm_history_delete_notice_p2": "ഈ പ്രവർത്തനം പഴയപടിയാക്കാനാവില്ല.",
  "menu_action_save_to_pocket": "പോക്കറ്റിലേയ്ക്ക് സംരക്ഷിയ്ക്കുക",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "തിരയുക",
  "search_header": "{search_engine_name} തിരയുക",
  "search_web_placeholder": "ഇൻറർനെറ്റിൽ തിരയുക",
  "section_disclaimer_topstories": "വെബിലെ ഏറ്റവും രസകരമായ അറിവുകൾ, നിങ്ങൾ വായിച്ചവ അടിസ്ഥാനമാക്കി തിരഞ്ഞെടുത്തത്. ഇപ്പോൾ മോസില്ലയുടെ ഭാഗമായ പോക്കറ്റിൽ നിന്നും.",
  "section_disclaimer_topstories_linktext": "എങ്ങനെ പ്രവര്‍ത്തിക്കുന്നു എന്ന് കാണുക.",
  "section_disclaimer_topstories_buttontext": "ശരി, മനസ്സിലായി",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "നിങ്ങളുടെ പുതിയ ടാബ് താള് ഇഷ്ടാനുസൃതമാക്കുക",
  "settings_pane_topsites_header": "മുന്നേറിയ സൈറ്റുകൾ",
  "settings_pane_highlights_header": "ഹൈലൈറ്റുകൾ",
  "settings_pane_highlights_options_bookmarks": "ബുക്ക്മാർക്കുകൾ",
  "settings_pane_snippets_header": "ലഘു കുറിപ്പുകൾ",
  "edit_topsites_button_text": "തിരുത്തുക",
  "edit_topsites_edit_button": "ഈ സൈറ്റ് തിരുത്തുക",
  "topsites_form_add_header": "പുതിയ മികച്ച സൈറ്റുകൾ",
  "topsites_form_edit_header": "മികച്ച സൈറ്റ് ലിസ്റ്റ് തിരുത്തൂ",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "തലക്കെട്ട് നൽകൂ",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "വെബ്URLനൽകൂ",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "ചേർക്കൂ",
  "topsites_form_save_button": "സംരക്ഷിയ്ക്കൂ",
  "topsites_form_cancel_button": "ഒഴിവാക്കൂ",
  "topsites_form_url_validation": "പ്രവർത്തിയ്ക്കുന്ന URL ആവശ്യമാണ്",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "ജനപ്രിയ വിഷയങ്ങൾ:",
  "pocket_read_even_more": "കൂടുതൽ ലേഖനങ്ങൾ കാണുക",
  "highlights_empty_state": "ബ്രൗസിംഗ് ആരംഭിക്കുക, നിങ്ങൾ സമീപകാലത്ത് സന്ദർശിച്ചതോ ബുക്ക്മാർക്ക് ചെയ്തതോ ആയ മികച്ച ലേഖനങ്ങളിൽ നിന്നോ, വീഡിയോകളിൽ നിന്നോ, മറ്റു പേജുകളിൽ നിന്നോ ചിലത് ഞങ്ങൾ ഇവിടെ കാണിക്കും.",
  "topstories_empty_state": "നിങ്ങൾ ഇവിടെ വരെ എത്തി. {Provider}ൽ നിന്നുള്ള കൂടുതൽ പ്രധാന വാർത്തകൾക്കായി പിന്നീട് വീണ്ടും പരിശോധിക്കുക. കാത്തിരിക്കാൻ പറ്റില്ലേ? വെബിൽ നിന്ന് കൂടുതൽ മികച്ച കഥകൾ കണ്ടെത്തുന്നതിന് ഒരു ജനപ്രിയ വിഷയം തിരഞ്ഞെടുക്കുക.",
  "manual_migration_explanation2": "മറ്റൊരു ബ്രൗസറിൽ നിന്നുള്ള ബുക്ക്മാർക്കുകൾ, ചരിത്രം, പാസ്വേഡുകൾ എന്നിവ ഉപയോഗിച്ച് ഫയർഫോക്സ് പരീക്ഷിക്കുക.",
  "manual_migration_cancel_button": "വേണ്ട, നന്ദി",
  "manual_migration_import_button": "ഇപ്പോൾ ഇറക്കുമതി ചെയ്യുക",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "ലോഡ്ചെയ്യുന്നു…",
  "header_stories": "മികച്ച ലേഖനങ്ങൾ",
  "header_visit_again": "വീണ്ടും സന്ദർശിക്കുക",
  "header_bookmarks": "അടുത്തിടെയുള്ള ബുക്ക്മാർക്കുകൾ",
  "header_bookmarks_placeholder": "നിങ്ങൾക്ക് ഇതുവരെ ബുക്ക്മാർക്കുകൾ ഇല്ല.",
  "header_stories_from": "എവിടെ നിന്നും",
  "type_label_synced": "മറ്റു ഉപകരണങ്ങളുമായി സാമ്യപ്പെടുക",
  "type_label_open": "തുറക്കുക",
  "type_label_topic": "വിഷയം",
  "type_label_now": "ഇപ്പോൾ",
  "menu_action_copy_address": "വിലാസം പകർത്തുക",
  "menu_action_email_link": "ഇമെയിൽ വിലാസം…",
  "search_for_something_with": "തിരയാൻ {search_term} : എന്നത് ഉപയോഗിയ്ക്കുക",
  "search_settings": "തിരയാനുള്ള രീതികൾ മാറ്റുക",
  "section_info_option": "വിവരം",
  "section_info_send_feedback": "ഫീഡ്ബാക്ക് അയയ്ക്കുക",
  "section_info_privacy_notice": "സ്വകാര്യതാ അറിയിപ്പ്",
  "welcome_title": "പുതിയ ജാലകത്തിലേക്കു സ്വാഗതം",
  "welcome_body": "നിങ്ങളുടെ ഏറ്റവും ശ്രദ്ധേയമായ അടയാളങ്ങൾ, ലേഖനങ്ങൾ, വീഡിയോകൾ, കൂടാതെ നിങ്ങൾ സമീപകാലത്ത് സന്ദർശിച്ച താളുകൾ എന്നിവ കാണിക്കുന്നതിനായി ഫയർഫോക്സ് ഈ ഇടം ഉപയോഗിക്കും, അതിനാൽ നിങ്ങൾക്ക് എളുപ്പത്തിൽ അവയിലേക്ക് തിരിച്ചു പോകാം.",
  "welcome_label": "താങ്കളുടെ ഹൈലൈറ്റ്സ് തിരിച്ചറിയുന്നു",
  "time_label_less_than_minute": "<1 മിനിറ്റ്",
  "time_label_minute": "{number} മിനിറ്റ്",
  "time_label_hour": "{number} മിനിറ്റ്",
  "time_label_day": "{number} മിനിറ്റ്",
  "settings_pane_header": "പുതിയ ടാബിന്റെ മുൻഗണനകൾ",
  "settings_pane_body2": "നിങ്ങൾ ഈ താളിൽ കാണുന്നത് തിരഞ്ഞെടുക്കുക.",
  "settings_pane_search_header": "തിരയുക",
  "settings_pane_search_body": "പുതിയ ടാബിൽ നിന്ന് ഇന്റർനെറ്റിൽ തിരയുക.",
  "settings_pane_topsites_body": "നിങ്ങൾ കൂടുതൽ സന്ദർശിക്കുന്ന വെബ്‌സൈറ്റുകളിൽ പ്രവേശിക്കുക.",
  "settings_pane_topsites_options_showmore": "രണ്ടു വരികൾ കാണിയ്ക്കുക",
  "settings_pane_bookmarks_header": "അടുത്തിടെയുള്ള ബുക്ക്മാർക്കുകൾ",
  "settings_pane_bookmarks_body": "നിങ്ങളുടെ പുതിയതായി സൃഷ്ടിച്ച ബുക്ക്മാർക്കുകൾ ഒരു സ്ഥലത്ത്.",
  "settings_pane_visit_again_header": "വീണ്ടും സന്ദർശിക്കുക",
  "settings_pane_visit_again_body": "നിങ്ങൾ ഓർത്തുവയ്ക്കാനോ അല്ലെങ്കിൽ തിരികെ ചെല്ലാനോ ആഗ്രഹിക്കുന്ന ബ്രൌസിംഗ് ചരിത്രത്തിന്റെ ഭാഗങ്ങൾ നിങ്ങൾക്ക് ഫയർഫോക്സ് കാണിച്ച് തരും.",
  "settings_pane_highlights_body2": "നിങ്ങൾ സമീപകാലത്ത് സന്ദർശിച്ചതോ അല്ലെങ്കിൽ ബുക്ക്മാർക്ക് ചെയ്തതോ ആയ രസകരമായ കാര്യങ്ങളിലേക്ക് വഴി കണ്ടെത്തുക.",
  "settings_pane_highlights_options_visited": "സന്ദർശിച്ച സൈറ്റുകൾ",
  "settings_pane_snippets_body": "മോസില്ലയിൽ നിന്നും ഫയർഫോക്സ്, ഇന്റർനെറ്റ് സംസ്കാരം, വല്ലപ്പോഴുമുള്ള ക്രമമില്ലാത്ത മെമെ, എന്നിവയിൽ ചെറുതും മധുരവുമായ പരിഷ്കരണങ്ങൾ വായിക്കുക.",
  "settings_pane_done_button": "തീർന്നു",
  "settings_pane_topstories_options_sponsored": "സ്പോൺസർ ചെയ്തവ കാണിക്കുക",
  "edit_topsites_button_label": "നിങ്ങളുടെ മുന്നേറിയ സൈറ്റുകളുടെ വിഭാഗം ഇഷ്ടാനുസൃതമാക്കുക",
  "edit_topsites_showmore_button": "കൂടുതൽ കാണിക്കുക",
  "edit_topsites_showless_button": "കുറച്ച് കാണിക്കുക",
  "edit_topsites_done_button": "തീർന്നു",
  "edit_topsites_pin_button": "ഈ സൈറ്റ് പിൻ ചെയ്യുക",
  "edit_topsites_unpin_button": "ഈ സൈറ്റ് അണ്‍പിന്‍ ചെയ്യുക",
  "edit_topsites_dismiss_button": "ഈ സൈറ്റ് പുറത്താക്കുക",
  "edit_topsites_add_button": "ചേര്‍ക്കുക",
  "pocket_feedback_header": "250 ലക്ഷം പേരാൽ തെരഞ്ഞെടുക്കപ്പെട്ട വെബിലെ ഏറ്റവും മികച്ചവയാണിവ.",
  "pocket_description": "മോസില്ലയുടെ ഭാഗമായ, പോക്കറ്റിന്റെ സഹായം കൊണ്ട്, നിങ്ങൾക്ക് കണ്ടെത്താനാവാത്ത ഉയർന്ന നിലവാരമുള്ള ഉള്ളടക്കം കണ്ടെത്തുക."
};
